@@ -151,7 +151,7 @@ double gaussianProduct(const double& mu1, const double& mu2, const double& sd1,
 // [[Rcpp::export]]
 double logLikelihoodNull(const NumericVector& theta, const NumericVector& logRr, const NumericVector& seLogRr) {
   if (theta[1] <= 0) {
-    return(99999);
+    return(R_PosInf);
   }
   double result(0);
   double sd = 1/sqrt(theta[1]);
@@ -160,13 +160,13 @@ double logLikelihoodNull(const NumericVector& theta, const NumericVector& logRr,
       result = result - R::dnorm(theta[0], logRr[i], seLogRr[i], true);
     }
   } else {
-    double x = 0;
     for (unsigned int i = 0; i < logRr.size(); i++) {
       result = result - log(gaussianProduct(logRr[i], theta[0], seLogRr[i], sd));
     }
   }
-  if (result == 0 || result > 1e10)
-    result = 99999;
+  // if (result == 0 || result > 1e10)
+  if (result == 0)
+    result = R_PosInf;
   return(result);
 }
 
